@@ -18,6 +18,471 @@ import functools
 ## Fix Font links and names in description
 
 def default(Strng):
+    Strng = Strng.replace("\uF001", "").replace("\u05CC", "").\
+        replace("ʻʻ", "").replace('\u05CD', '') ## remove token characters for specialized processing
+
+    return Strng
+
+def syriacVowelsBelow(Strng):
+
+    return Strng
+
+def syriacWesternOToU(Strng):
+
+    return Strng
+
+def olddogra(Strng):
+
+    return Strng
+
+def ISO259Target(Strng):
+    replacements = [('b', 'ḃ'), ('p', 'ṗ'), ('k', 'k̇'), ('ḵ', 'k'), ('v', 'b'), ('f', 'p'), ('꞉', '\u0307'),\
+         ('š̪', 'ś'), ('š̮', 'š'), ('š', 's̀'),
+        ('ā', 'å'), ('e', 'ȩ'), ('ō', 'ŵ'), ('ū', 'ẇ'), ('\u033D', '°'), ('ĕ', 'ḝ')
+    ]
+
+    for x, y in replacements:
+        Strng = Strng.replace(x, y)
+
+    Strng = Strng.replace('\u00B0\u0307', '\u0307\u00B0')
+
+    return Strng
+
+def HebrewSBLTarget(Strng):
+    replacements = [('v', 'ḇ'), ('f', 'p̄'), ('d', 'ḏ'), ('ḏ꞉', 'd'), \
+        ('g', 'ḡ'), ('ḡ꞉', 'g'),\
+            ('t', 'ṯ'), ('ṯ꞉', 't'),
+         ('š̪', 'ś'), ('š̮', 'š'),
+        ('ō', 'ô'), ('o', 'ō'), ('ū', 'û'), ('\u033D', 'ĕ')
+    ]
+
+    for x, y in replacements:
+        Strng = Strng.replace(x, y)
+
+    Strng = Strng.replace('ĕ꞉', '꞉ĕ')
+
+    if '\u05CE' in Strng:
+        Strng = Strng.replace('ḏ', 'd').replace('ṯ', 't').replace('ḡ', 'g').replace('\u05CE', '')
+
+    Strng = Strng.replace('\u00B0\u0307', '\u0307\u00B0')
+
+    return Strng
+
+def removetddash(Strng):
+    Strng += '\u05CE'
+
+    Strng = Strng.replace('d', 'd꞉').replace('t', 't꞉').replace('g', 'g꞉')
+    Strng = Strng.replace('ḏ', 'd').replace('ṯ', 't').replace('ḡ', 'g').replace('\u05CE', '')
+
+    return Strng
+
+
+def ISO259Source(Strng):
+
+    return Strng
+
+def ISO233Source(Strng):
+
+    return Strng
+
+def HebrewSBLSource(Strng):
+
+    return Strng
+
+def PersianDMGSBLSource(Strng):
+
+    return Strng
+
+def ISO233Target(Strng):
+    replacements = [('j', 'ǧ'), ('g', 'ǧ'), ('ḧ', 'ẗ'), ('ḫ', 'ẖ'), ('a̮', 'ỳ'), ('ˀ', 'ˈ'), \
+        ('aⁿ', 'á'), ('iⁿ', 'í'), ('uⁿ', 'ú'), ('ā̂', 'ʾâ'), ('\u033D', '')]
+
+    for x, y in replacements:
+        Strng = Strng.replace(x, y)
+
+    return Strng
+
+def inherentAO(Strng):
+    Strng = Strng.replace('a', 'ô')
+
+    return Strng
+
+def BengaliOldRA(Strng):
+    Strng = Strng.replace('র', 'ৰ')
+
+    return Strng
+
+def PersianDMGTarget(Strng):
+    replacements = [('ḏ', 'ẕ'), ('ḍ', 'ż'), ('ṯ', 's̱'), ('j', 'ǧ'), ('ˀ','ʼ'), ('ʔ', 'ʼ'), ('ȳ', 'ye'), ("ā̂", "ā"), ('\u033D', '')]
+
+    for x, y in replacements:
+        Strng = Strng.replace(x, y)
+
+    return Strng
+
+def arabizeLatn(Strng, target='semitic'):
+    cons = '(' + '|'.join(GM.SemiticConsonants) + ')'
+
+    # opt 1
+    Strng = re.sub(cons + '(ʾ)', r'\1' + 'ā', Strng)
+    ### implement ths as a preoption for all semitic scripts
+
+    #print('Arabized string is', Strng)
+
+    ## Strng = re.sub('ʾ[aiu]ⁿ', '')
+
+    if target == 'indic':
+        Strng = Strng.replace('ʾā', 'ā̂')
+
+    # opt 2
+    if target != 'indic':
+        Strng = re.sub('ʾ', 'a', Strng)
+    else:
+        Strng = re.sub('ʾ', 'â', Strng)
+
+    # opt 3
+    Strng = re.sub('(a̮|ā̮)', 'ā', Strng)
+    Strng = re.sub('ˀ?ā̮̂', 'ʼā', Strng)
+
+    if target != 'indic':
+        Strng = re.sub('[ˀʔ]', 'ʼ', Strng)
+    else:
+         Strng = re.sub('[ˀ]', '', Strng)
+
+    if target != 'indic':
+        Strng = LatnInitialVowels(Strng, 'ʾ') ## Check this
+
+    if target != 'indic':
+        Strng = re.sub('ʼʾ', 'ʼ', Strng)
+
+    if target != 'indic':
+        Strng = re.sub('\u033d', '', Strng)
+
+    Strng = re.sub('(ā)([iau])(ⁿ)', r'\2\3', Strng)
+
+    #print('Arabized string is', Strng)
+
+    return Strng
+
+def BengaliSwitchYaYYa(Strng):
+    Strng = re.sub('(?<!\u09CD)য', '@#$', Strng)
+    Strng = re.sub('য়', 'য', Strng)
+    Strng = Strng.replace('@#$', 'য়')
+
+    return Strng
+
+def AlephMaterLectionis(Strng, target='semitic'):
+    cons = '(' + '|'.join(GM.SemiticConsonants) + ')'
+
+    # opt 1
+    Strng = re.sub(cons + '(ʾ)', r'\1' + 'ā', Strng)
+
+    return Strng
+
+def urduizeLatn(Strng, target='semitic'):
+    cons = '(' + '|'.join(GM.SemiticConsonants) + ')'
+
+    # opt 1
+    Strng = re.sub(cons + '(ʾ)', r'\1' + 'ā', Strng)
+
+    if target == 'indic':
+        Strng = Strng.replace('ʾā', 'ā̂') ## Check this
+
+    # opt 2
+    Strng = re.sub('ʾ', 'â', Strng)
+
+    # opt 3
+    Strng = re.sub('[ˀʔ]', 'ʾ', Strng)
+    Strng = re.sub('(a̮|ā̮)', 'ā', Strng)
+    Strng = re.sub('ˀ?ā̮̂', 'ʼā', Strng)
+
+    if target != 'indic':
+        Strng = re.sub('\u033d', '', Strng)
+
+    if target != 'indic':
+        Strng = LatnInitialVowels(Strng)
+
+    Strng = re.sub('(ā)([iau])(ⁿ)', r'\2\3', Strng)
+
+    return Strng
+
+def syricizeLatn(Strng, target='semitic'):
+    cons = '(' + '|'.join(GM.SemiticConsonants) + ')'
+
+    # opt 3
+    if target != 'indic':
+        Strng = re.sub('â', 'ʾa', Strng)
+        Strng = re.sub('ā̂', 'ʾā', Strng)
+        Strng = re.sub("ê", "ʾe", Strng)
+        Strng = re.sub("ē̂", "ʾē", Strng)
+
+    if target != 'indic':
+        Strng = LatnInitialVowels(Strng)
+
+    return Strng
+
+def hebraizeLatn(Strng, target='semitic'):
+    #print('Hebraizing Latin')
+    if target != 'indic':
+        Strng = LatnInitialVowels(Strng, 'ʾ')
+
+    return Strng
+
+def syriacRoman(Strng):
+    Strng = Strng.replace('v', 'ḇ').replace('ġ','ḡ').replace('ḫ','ḵ').replace('f','p̄')
+
+    return Strng
+
+def alephAyinLatnAlternate(Strng):
+    Strng = Strng.replace('ʾ', 'ʼ').replace('ʿ', 'ʽ')
+
+    return Strng
+
+
+def alephAyinLatnAlternate2(Strng):
+    Strng = Strng.replace('ʾ', 'ʔ').replace('ʿ', 'ʕ')
+
+    return Strng
+
+def ArabRemoveAdditions(Strng):
+    Strng = Strng.replace('ڨ', 'ج').replace('ڤ', 'ف').replace('پ', 'ف')
+
+    return Strng
+
+def arabicRemoveAdditionsPhonetic(Strng):
+
+    Strng = Strng.replace('ڨ', 'غ').replace('ڤ', 'ف').replace('پ', 'ب')
+
+    return Strng
+
+def removeSemiticLetters(Strng):
+    Strng = Strng.replace('ṭ', 't').replace('ḥ', 'h').replace('ḍ', 'z').replace('ḏ', 'z').replace('ẓ', 'z')\
+        .replace('w', 'v').replace('ʿ', 'ʾ').replace('ṣ', 's')
+
+    return Strng
+
+def removeNikkud(Strng):
+    nikkuds = ["\u05B7","\u05B8","\u05B4","\u05B4י","\u05BB", "\u05C2", "\u05C1",\
+    "\u05B6","\u05B5","\u05B9","וֹ","\u05B1","\u05B2","\u05B3","\u05BC","\u05B0", "\u05C7"]
+
+    for nikkud in nikkuds:
+        Strng = Strng.replace(nikkud, '')
+
+    return Strng
+
+def LatnInitialVowels(Strng, initLetter=''):
+    initVow = 'â ā̂ î ī̂ û ū̂ ê ē̂ âŷ ô ō̂ âŵ'.split(' ')
+    nonInitVow = 'a ā i ī u ū e ē aŷ o ō aŵ'.split(' ')
+
+    for x, y in zip(initVow, nonInitVow):
+        Strng = Strng.replace(x, initLetter+y)
+
+    Strng = Strng.replace('\u0302', '')
+
+    Strng = re.sub('\u033d', '', Strng)
+    #Strng = 'Vinodh'
+    return Strng
+
+def removeMajliyana(Strng):
+    Strng = Strng.replace('\u0330', '')
+
+    return Strng
+
+def removeRukkaka(Strng):
+    Strng = Strng.replace('\u0741', '')
+
+    return Strng
+
+def removeQussaya(Strng):
+    Strng = Strng.replace('\u0742', '')
+
+    return Strng
+
+def removeVowelsSyriac(Strng):
+    Strng = re.sub('[\u0732\u0735\u073C\u0738\u0739\u073F]', '', Strng)
+
+    Strng = re.sub('[ّܰܶܺܽܳ]', '', Strng)
+
+    return Strng
+
+def removeDiacriticsArabic(Strng):
+    diacrtics = ["\u0652", "\u064E", "\u0650", "\u064F"]
+
+    for diacritic in diacrtics:
+        Strng = Strng.replace(diacritic, '')
+
+    return Strng
+
+def removeSukunEnd(Strng):
+    Strng = re.sub('(\u0652)(\W|$)', r'\2', Strng)
+
+    return Strng
+
+def persianPaGaFaJa(Strng):
+    Strng = Strng.replace('پ', 'ف').replace('گ', 'ج')
+
+    return Strng
+
+def removeDiacriticsPersian(Strng):
+
+    return Strng
+
+def removeDiacriticsSyriac(Strng):
+
+    return Strng
+
+def useKtivMale(Strng):
+
+    return Strng
+
+def PhoneticMapping(Strng):
+
+    return Strng
+
+def ArabicGimelGaGha(Strng):
+    Strng = Strng.replace('ج', 'غ')
+
+    return Strng
+
+def ArabicGimelPaBa(Strng):
+    Strng = Strng.replace('ف', 'ب')
+
+    return Strng
+
+def IASTLOCBurmeseSource(Strng):
+    # remove marking for pure virama
+    Strng = Strng.replace('ʻ', '')
+
+    # restore superscript Ga into normal subjoined y, r , v, h
+    yrvh = Burmese.ConsonantMap[25:27] + Burmese.ConsonantMap[28:29] + Burmese.ConsonantMap[32:33]
+    yrvhPat = ''.join(yrvh)
+    Strng = re.sub(f'(\u103A)(\u1039)([{yrvhPat}])', r'\2\3', Strng)
+
+    # restrore special yrvh
+    virsub = '\u1039'
+    yrvhsub = ['\u103B','\u103C','\u103D','\u103E']
+
+    for x,y in zip(yrvh,yrvhsub):
+        # Undo Replace subjoining forms: exp-virama + y/r/v/h <- subjoining y/r/v/h
+        Strng = Strng.replace(virsub + x, y)
+
+    # u-Indep-i -> u-dep-i
+    Strng = Strng.replace('\u102Fဣ', '\u102D\u102F')
+
+    # reverse replace vowel + diac with vowels
+    vowDep = 'အော် အော အိ အီ အု အူ အေ'.split(' ')
+    vowIndep = 'ဪ ဩ ဣ ဤ ဥ ဦ ဧ'.split(' ')
+
+    for x, y in zip(vowDep, vowIndep):
+        Strng = Strng.replace('ʼ' + y, x)
+
+    # reverse mark a as glottalstop
+    Strng = Strng.replace('ʼအ', 'အ')
+
+    return Strng
+
+def removeSegmentSpacesBurmese(Strng):
+    # segment text into syllables
+    import regex
+
+    Strng = regex.sub('(\p{L}\p{M}*) (\p{L})', r'\1\2', Strng)
+    Strng = regex.sub('(\p{L}\p{M}*) (\p{L})', r'\1\2', Strng)
+
+    return Strng
+
+def IASTLOCBurmeseTarget(Strng):
+    #print(Strng)
+    # mark tone
+    Strng = Strng.replace('˳', '´')
+
+    # mark depaend au -> o'
+    Strng = Strng.replace('auʻ','oʻ')
+
+    # mark visarga as tone
+    Strng = Strng.replace('ḥ', '˝')
+
+    # sort subjoined consonants
+    # Strng = Strng.replace('‘‘', '')
+
+    # adhoc chars
+    chars_misc = {
+        "e*": "၏",
+        'n*': "၌",
+        'r*': '၍',
+        'l*': '၎'
+    }
+
+    for lat, bur in chars_misc.items():
+        Strng = Strng.replace(bur, lat)
+
+    Strng = Strng.replace('ṃ', 'ṁ')
+
+    return Strng
+
+### Add new consonants here when added to gimeltra_data
+def insertARomanSemitic(Strng):
+    Strng = Strng.replace('\u02BD', '')
+    consonantsAll = '(' + '|'.join(sorted(GM.SemiticConsonants, key = len, reverse=True)) + ')'
+    #above does not ocntain semitic consonants
+    vowelsAll = '(' + '|'.join(GM.SemiticVowels) + ')'
+    #print(Strng)
+    Strng = re.sub(consonantsAll + '(?![꞉ʰ])(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
+    Strng = re.sub('(꞉)(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
+    ## avoid double /a/ just in case
+    #Strng = Strng.replace('aa', 'a')
+    #Strng = re.sub(consonantsAll + '(?!' + vowelsAll + ')', r'\1' + 'a', Strng)
+
+
+    #print(Strng)
+
+    return Strng
+
+# Semitic Target
+def FixSemiticRoman(Strng, Target):
+    vir = '\u033D'
+    Strng = re.sub('ō̂̄̂', 'ō̂', Strng)
+
+    ## For Gemination
+    if "Arab" in Target:
+        consonantsAll = '(' + '|'.join(sorted(GM.CrunchSymbols(GM.Consonants, 'RomanSemitic'), key = len, reverse=True)) + ')'
+        Strng = re.sub(consonantsAll + vir + r'\1', r'\1' + '꞉', Strng)
+        #Strng = re.sub('(꞉)([aiuāīū])', r'\2\1', Strng)
+
+    # create nukta equivalents
+    # move nukta before /a/
+
+    Strng = re.sub("âQ", "ʿ", Strng)
+    Strng = re.sub('aQ', 'Qa', Strng)
+
+    SemiticIndic=[('ʾQā', 'ā̂Q'), ('ʾQi', 'îQ'), ('ʾQī', 'ī̂Q'), ('ʾQu', 'ûQ'), ('ʾQū', 'ū̂Q'), ('ʾQe', 'êQ'), ('ʾQē', 'ē̂Q'),\
+        ('ʾQo', 'ôQ'), ('ʾQō', 'ō̂Q'), ('ṣ', 'sQ'), ('ʿ', 'ʾQ'), \
+                                 ('ṭ', 'tQ'), ('ḥ', 'hQ'), ('ḍ', 'dQ'), ('p̣', 'pQ'), ('ž', 'šQ'), ('ž', 'zQ'), ('ẓ', 'jʰQ'), ('ḏ', 'dʰQ'), ('ṯ', 'tʰQ'),
+                                     ('w', 'vQ')
+                        ]
+    for s, i in SemiticIndic:
+        Strng = Strng.replace(i, s)
+
+    Strng = Strng.replace('\u033d\u033d', '\u033d')
+
+    #print('Strng is ' + Strng)
+
+    return Strng
+
+def ArabAtoAleph(Strng):
+    Strng = Strng.replace('أ', 'ا')
+
+
+    return Strng
+
+def estrangelasyriac(Strng):
+
+    return Strng
+
+def easternsyriac(Strng):
+
+    return Strng
+
+def westernsyriac(Strng):
 
     return Strng
 
@@ -29,6 +494,14 @@ def sundapura(Strng):
 
     return Strng
 
+def readableItrans(Strng):
+    pairsReadable = [('R^i','RRi'), ('R^I','RRii'), ('',''), ('',''), ('A', 'aa'), ('I', 'ii'), ('U', 'uu'), ('Ch', 'chh'), ('kSh','x'), ('M', '.m')]
+
+    for x, y in pairsReadable:
+        Strng = Strng.replace(x,y)
+
+    return Strng
+
 def NasalTilde(Strng):
     Strng = re.sub('(m̐|ṃ|ṁ)', '\u0303', Strng)
 
@@ -46,6 +519,37 @@ def vtobJapanese(txt):
 
     return txt
 
+def SogdReshAyin(Strng):
+    Strng = Strng.replace('𐼽', '𐽀')
+
+    return Strng
+
+def SogoReshAyinDaleth(Strng):
+    Strng = Strng.replace('𐼓','𐼘')
+
+    return Strng
+
+def arabPaFa(Strng):
+
+    return Strng.replace('پ','ف')
+
+
+def arabChaSa(Strng):
+
+    return Strng.replace('چ', 'س')
+
+def gainGimel(Strng):
+    return Strng.replace('עׄ','ג')
+
+def tavTwodot(Strng):
+    return Strng.replace('ת','ת̈')
+
+def tavThreedot(Strng):
+    return Strng.replace('תׄ','ת֒')
+
+def gainGimel(Strng):
+    return Strng.replace('ק','ק̈')
+
 def tokushuon(txt):
    txt = txt.replace('si', 'suxi').replace('zi', 'zuxi')
    txt = txt.replace('yi','ixi')
@@ -250,8 +754,8 @@ def HebrewnonFinalShort(Strng):
 
     uVowels = ['וֹ', 'וּ']
 
-    for s in uVowels:
-        Strng = re.sub('(' + s + ')' + '(׳?)' + '(?!' + consonantsAll + ')', r'\1\2' + 'א', Strng )
+    #for s in uVowels:
+        #Strng = re.sub('(' + s + ')' + '(׳?)' + '(?!' + consonantsAll + ')', r'\1\2' + 'א', Strng )
 
     return Strng
 
@@ -1500,7 +2004,7 @@ def MalayalamChillu(Strng, reverse=False, preserve=False):
 
 def RemoveSchwa(Strng,Target):
 
-    vir = GM.CrunchSymbols(GM.VowelSigns,Target)[0]
+    vir = GM.CrunchSymbols(GM.VowelSigns,Target)[0] + GM.CrunchSymbols(GM.VowelSigns,Target)[0]
     ListC = '|'.join(GM.CrunchSymbols(GM.Consonants,Target))
     ListV = '|'.join(GM.CrunchSymbols(GM.Vowels,Target))
     ListVS = '|'.join(GM.CrunchSymbols(GM.VowelSignsNV,Target))
@@ -1547,7 +2051,7 @@ def GurmukhiTippiBindu(Strng): # Check this Function
     Bindi = Gurmukhi.AyogavahaMap[1];
     Tippi = '\u0A70'
     ListTippi = '|'.join(GM.CrunchSymbols(GM.Consonants, 'Gurmukhi')+[Gurmukhi.VowelMap[x] for x in [0,2,3,4]]
-        +[Gurmukhi.VowelSignMap[1]]+[Gurmukhi.VowelSignMap[3]])
+        +[Gurmukhi.VowelSignMap[1]]+[Gurmukhi.VowelSignMap[3]]+[Gurmukhi.VowelSignMap[4]])
 
     Char = '|'.join(GM.CrunchSymbols(GM.Consonants, 'Gurmukhi') + GM.CrunchSymbols(GM.Vowels, 'Gurmukhi'))
 
@@ -1580,6 +2084,34 @@ def khandatabatova(Strng):
 
     return Strng
 
+def BengaliRaBa(Strng):
+    Strng = Strng.replace('ব', 'ৰ').replace('ভ়', 'ব').replace('ৰু', 'ৰ‌ু').replace('ৰূ', 'ৰ‌ূ')
+    ## Avoid bba -> rra
+    ## break all ba conjuncts
+    Strng = Strng.replace('\u09CD\u09F0', '\u09CD\u200C\u09F0')
+
+    ## bra/bya bru fix
+    Strng = re.sub('(\u09F0)(\u09CD)([\u09B0\u09AF])', r'\1' + '\u200D' + r'\2\3', Strng)
+    Strng = re.sub('(\u09F0)(\u09CD)', r'\1\2' + '\u200C', Strng)
+
+
+    ## rba
+    Strng = Strng.replace('র্‌ৰ', 'ৰ্ৰ')
+
+    return Strng
+
+def BengaliIntervocalicDDA(Strng):
+    Target = 'Bengali'
+
+    ListC = '|'.join(GM.CrunchSymbols(GM.Characters, Target)+[GM.CrunchList('SignMap',Target)[0]] + ['ৰ'])
+
+    replacements = [('ড', 'ড়'), ('ঢ', 'ঢ়')]
+
+    for x, y in replacements:
+        Strng = re.sub('('+ListC+')'+ GM.VedicSvaras + x,r'\1\2'+y,Strng)
+
+    return Strng
+
 def KhandaTa(Strng,Target, reverse=False): #Check for Bhakt - Khanda Ta not formed
 
     ta = GM.CrunchSymbols(GM.Consonants, Target)[15]
@@ -2036,8 +2568,27 @@ def ThaiLaoTranscription(Strng,Script,shortA,shortAconj,reverse=False, anusvaraC
 
         Strng = re.sub("(?<!["+EAIO+"])"+"("+cons+")"+"(?!["+AIUVir+"])",r'\1'+shortA,Strng)
         Strng = re.sub("("+shortA+")"+"(?=("+cons+")"+"("+vir+"))",shortAconj,Strng)
+
+
+        # prahlada -> ปรหลาทะ
+        Strng = Strng.replace(shortAconj + 'ห'+vir, 'ห'+vir)
+        # katra -> กะตระ
+        Strng = re.sub("("+shortAconj+")"+ "(.)("+vir+")([รล])",shortA + r'\2\3\4',Strng)
+
+        ## swap rl
+
+        consswap = "|".join(GM.CrunchSymbols(GM.Consonants, "Thai"))
+        Strng = re.sub("("+consswap+")"+"("+vir+")"+"(["+EAIO+"])"+"([รล])",r"\3\1\2\4",Strng)
+
+        ## katro -> กะโตร
+        Strng = re.sub(shortAconj +"(["+EAIO+"])", shortA + r'\1', Strng)
+
         Strng = Strng.replace(vir, '')
 
+        ## Fix sarva --> srrva ; สัรวะ ->
+        Strng = Strng.replace(shortAconj + 'ร', 'รร')
+
+
         ## Fix Purevowels
 
     else:
@@ -2056,7 +2607,11 @@ def ThaiLaoTranscription(Strng,Script,shortA,shortAconj,reverse=False, anusvaraC
             Strng = re.sub('(?<!โ)' + '(?<!แ)'+'(?<!เ)' + '('+aVow+')' + '(?<!เ)' + shortA+"|"+shortAconj, r"\1",Strng)
             Strng = re.sub('(' + consOnly + ')' + '(?<!า|โ|แ|เ)' + shortA+"|"+shortAconj, r"\1",Strng)
 
+            # ธรรมะ -> dharma
+            Strng = re.sub(vir + 'รฺรฺ', 'รฺ', Strng)
 
+            # พรหมา  -> Brahma
+            Strng = re.sub(vir + 'หฺ', 'หฺ', Strng)
 
     return Strng
 
@@ -2234,6 +2789,8 @@ def ThaiTranscription(Strng, anusvaraChange = True):
 
     Strng = Strng.replace('ะงัง', '\u0E31งํ')
 
+    #print(Strng)
+
 #    shortA = u'\u0E30'
 #    shortAconj = u'\u0E31'
 #    cons = "|".join(GM.CrunchSymbols(GM.Consonants, "Thai")+Thai.VowelMap[0:1])
